@@ -73,16 +73,16 @@ bug_buddy_init (void)
 
   argv = g_ptr_array_sized_new (12);
   g_ptr_array_add (argv, gdb_path);
-  g_ptr_array_add (argv, "-batch");
-  g_ptr_array_add (argv, "-nx");
-  g_ptr_array_add (argv, "-ex");
+  g_ptr_array_add (argv, (gchar *)"-batch");
+  g_ptr_array_add (argv, (gchar *)"-nx");
+  g_ptr_array_add (argv, (gchar *)"-ex");
   g_ptr_array_add (argv, g_strdup_printf ("attach %"G_PID_FORMAT, getpid ()));
-  g_ptr_array_add (argv, "-ex");
-  g_ptr_array_add (argv, "info threads");
-  g_ptr_array_add (argv, "-ex");
-  g_ptr_array_add (argv, "thread apply all bt");
-  g_ptr_array_add (argv, "-ex");
-  g_ptr_array_add (argv, "info sharedlibrary");
+  g_ptr_array_add (argv, (gchar *)"-ex");
+  g_ptr_array_add (argv, (gchar *)"info threads");
+  g_ptr_array_add (argv, (gchar *)"-ex");
+  g_ptr_array_add (argv, (gchar *)"thread apply all bt");
+  g_ptr_array_add (argv, (gchar *)"-ex");
+  g_ptr_array_add (argv, (gchar *)"info sharedlibrary");
   g_ptr_array_add (argv, NULL);
   gdb_argv = (gchar **)g_ptr_array_free (argv, FALSE);
 
