@@ -1,6 +1,6 @@
 /* bug-buddy.h
  *
- * Copyright (C) 2017 Christian Hergert <christian@hergert.me>
+ * Copyright © 2017 Christian Hergert <christian@hergert.me>
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -16,13 +16,10 @@
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
-#ifndef BUG_BUDDY_H
-#define BUG_BUDDY_H
+#pragma once
 
 G_BEGIN_DECLS
 
 void bug_buddy_init (void);
 
 G_END_DECLS
-
-#endif /* BUG_BUDDY_H */
