@@ -456,9 +456,11 @@ ide_buffer_manager_load_file__load_cb (GObject      *object,
   g_autoptr(IdeTask) task = user_data;
   g_autofree gchar *guess_contents = NULL;
   g_autofree gchar *content_type = NULL;
+  g_autofree gchar *truncated = NULL;
   GtkSourceFileLoader *loader = (GtkSourceFileLoader *)object;
   IdeBufferManager *self;
   const gchar *path;
+  const gchar *dot;
   IdeContext *context;
   LoadState *state;
   GtkTextIter iter;
@@ -540,8 +542,15 @@ ide_buffer_manager_load_file__load_cb (GObject      *object,
   gtk_text_iter_forward_chars (&end, 1024);
   guess_contents = gtk_text_iter_get_slice (&iter, &end);
   path = ide_file_get_path (state->file);
-  content_type = g_content_type_guess (path, (const guchar *)guess_contents,
-                                       strlen (guess_contents), &uncertain);
+
+  /* Remove the ".in" suffix for files that are expanded at build time. */
+  if ((dot = strrchr (path, '.')))
+    path = truncated = g_strndup (path, dot - path);
+
+  content_type = g_content_type_guess (path,
+                                       (const guchar *)guess_contents,
+                                       strlen (guess_contents),
+                                       &uncertain);
   if (content_type && !uncertain)
     _ide_file_set_content_type (state->file, content_type);
 
@@ -1166,6 +1175,24 @@ ide_buffer_manager_save_file_async (IdeBufferManager     *self,
       IDE_EXIT;
     }
 
+  /*
+   * In-case the directory for the file does not exist yet, or has been moved
+   * since we saved things locally, create the directory chain.
+   */
+  {
+    GFile *gfile = ide_file_get_file (file);
+    g_autoptr(GFile) parent = g_file_get_parent (gfile);
+    g_autoptr(GError) error = NULL;
+
+    /* It would be nice to do this async in the future... */
+    if (!g_file_make_directory_with_parents (parent, cancellable, &error) &&
+        !g_error_matches (error, G_IO_ERROR, G_IO_ERROR_EXISTS))
+      {
+        ide_task_return_error (task, g_steal_pointer (&error));
+        IDE_EXIT;
+      }
+  }
+
   context = ide_object_get_context (IDE_OBJECT (self));
   ide_context_hold_for_object (context, task);
 
@@ -2104,6 +2131,7 @@ ide_buffer_manager_apply_edits_buffer_loaded (GObject      *object,
   g_autoptr(GError) error = NULL;
   g_autoptr(IdeBuffer) buffer = NULL;
   EditState *state;
+  IdeFile *file;
 
   IDE_ENTRY;
 
@@ -2131,6 +2159,10 @@ ide_buffer_manager_apply_edits_buffer_loaded (GObject      *object,
   if (state->failed)
     IDE_EXIT;
 
+  /* Save the buffer for future use when applying edits */
+  file = ide_buffer_get_file (buffer);
+  g_hash_table_insert (state->buffers, g_object_ref (file), g_object_ref (buffer));
+
   /* If this is the last buffer to load, then we can go apply the edits. */
   if (state->count == 0)
     {
