@@ -57,8 +57,8 @@ static GParamSpec *properties [N_PROPS];
 static void
 get_build_flags_data_free (GetBuildFlagsData *data)
 {
-  dzl_clear_pointer (&data->files, g_ptr_array_unref);
-  dzl_clear_pointer (&data->flags, g_hash_table_unref);
+  g_clear_pointer (&data->files, g_ptr_array_unref);
+  g_clear_pointer (&data->flags, g_hash_table_unref);
   g_slice_free (GetBuildFlagsData, data);
 }
 
@@ -201,7 +201,7 @@ ide_build_system_real_get_build_flags_for_files_async (IdeBuildSystem       *sel
                                        g_object_unref,
                                        (GDestroyNotify)g_strfreev);
 
-  ide_task_set_task_data (task, data, (GDestroyNotify)get_build_flags_data_free);
+  ide_task_set_task_data (task, data, get_build_flags_data_free);
 
   ide_build_system_get_build_flags_async (self,
                                           g_ptr_array_index (files, 0),
@@ -492,12 +492,12 @@ ide_build_system_get_build_flags_for_files_async (IdeBuildSystem       *self,
 }
 
 /**
- * ide_build_system_get_build_flags_for_files_finish: (skip)
+ * ide_build_system_get_build_flags_for_files_finish:
  * @self: an #IdeBuildSystem
  * @result: a #GAsyncResult
  * @error: a location for a #GError or %NULL
  *
- * Returns: (element-type Gio.File GLib.Strv): a #GHashTable or #IdeFile to #GStrv
+ * Returns: (element-type Ide.File GStrv) (transfer full): a #GHashTable or #IdeFile to #GStrv
  *
  * Since: 3.28
  */
@@ -705,12 +705,12 @@ ide_build_system_get_build_flags_for_dir_async (IdeBuildSystem      *self,
 }
 
 /**
- * ide_build_system_get_build_flags_for_dir_finish: (skip)
+ * ide_build_system_get_build_flags_for_dir_finish:
  * @self: an #IdeBuildSystem
  * @result: a #GAsyncResult
  * @error: a location for a #GError or %NULL
  *
- * Returns: a #GHashTable of #IdeFile to #GStrv
+ * Returns: (element-type Ide.File GStrv) (transfer full): a #GHashTable of #IdeFile to #GStrv
  */
 GHashTable *
 ide_build_system_get_build_flags_for_dir_finish (IdeBuildSystem  *self,
