@@ -20,8 +20,6 @@
 
 #include "config.h"
 
-#include <dazzle.h>
-
 #include "buildsystem/ide-environment-variable.h"
 
 struct _IdeEnvironmentVariable
@@ -47,8 +45,8 @@ ide_environment_variable_finalize (GObject *object)
 {
   IdeEnvironmentVariable *self = (IdeEnvironmentVariable *)object;
 
-  dzl_clear_pointer (&self->key, g_free);
-  dzl_clear_pointer (&self->value, g_free);
+  g_clear_pointer (&self->key, g_free);
+  g_clear_pointer (&self->value, g_free);
 
   G_OBJECT_CLASS (ide_environment_variable_parent_class)->finalize (object);
 }
