@@ -20,7 +20,6 @@
 
 #include "config.h"
 
-#include <dazzle.h>
 #include <glib/gi18n.h>
 
 #include "doap/ide-doap-person.h"
@@ -99,8 +98,8 @@ ide_doap_person_finalize (GObject *object)
 {
   IdeDoapPerson *self = (IdeDoapPerson *)object;
 
-  dzl_clear_pointer (&self->email, g_free);
-  dzl_clear_pointer (&self->name, g_free);
+  g_clear_pointer (&self->email, g_free);
+  g_clear_pointer (&self->name, g_free);
 
   G_OBJECT_CLASS (ide_doap_person_parent_class)->finalize (object);
 }
