@@ -29,6 +29,7 @@
 #include "buffers/ide-buffer-manager.h"
 #include "editor/ide-editor-session-addin.h"
 #include "editor/ide-editor-perspective.h"
+#include "editor/ide-editor-private.h"
 #include "editor/ide-editor-view.h"
 #include "files/ide-file.h"
 #include "layout/ide-layout-grid.h"
@@ -49,6 +50,12 @@ typedef struct
   gint   column;
   gint   row;
   gint   depth;
+  struct {
+    gchar    *keyword;
+    gboolean  case_sensitive;
+    gboolean  regex_enabled;
+    gboolean  at_word_boundaries;
+  } search;
 } Item;
 
 typedef struct
@@ -85,6 +92,7 @@ static void
 clear_item (Item *item)
 {
   g_clear_pointer (&item->uri, g_free);
+  g_clear_pointer (&item->search.keyword, g_free);
 }
 
 static void
@@ -143,6 +151,7 @@ ide_editor_session_addin_foreach_view_cb (GtkWidget *widget,
     {
       IdeBuffer *buffer = ide_editor_view_get_buffer (IDE_EDITOR_VIEW (view));
       IdeFile *file = ide_buffer_get_file (buffer);
+      IdeEditorSearch *search = ide_editor_view_get_search (IDE_EDITOR_VIEW (view));
       Item item = { 0 };
 
       if (!ide_file_get_is_temporary (file))
@@ -152,6 +161,11 @@ ide_editor_session_addin_foreach_view_cb (GtkWidget *widget,
           item.uri = g_file_get_uri (gfile);
           get_view_position (view, &item.column, &item.row, &item.depth);
 
+          item.search.keyword = g_strdup (ide_editor_search_get_search_text (search));
+          item.search.at_word_boundaries = ide_editor_search_get_at_word_boundaries (search);
+          item.search.case_sensitive = ide_editor_search_get_case_sensitive (search);
+          item.search.regex_enabled = ide_editor_search_get_regex_enabled (search);
+
           IDE_TRACE_MSG ("%u:%u:%u: %s", item.column, item.row, item.depth, item.uri);
 
           g_array_append_val (items, item);
@@ -192,18 +206,26 @@ ide_editor_session_addin_save_async (IdeSessionAddin     *addin,
 
   g_array_sort (items, compare_item);
 
-  g_variant_builder_init (&builder, G_VARIANT_TYPE ("a(siii)"));
+  g_variant_builder_init (&builder, G_VARIANT_TYPE ("a(siiiv)"));
 
   for (guint i = 0; i < items->len; i++)
     {
       const Item *item = &g_array_index (items, Item, i);
+      GVariantBuilder sub;
+
+      g_variant_builder_init (&sub, G_VARIANT_TYPE ("a{sv}"));
+      g_variant_builder_add_parsed (&sub, "{'search.keyword',<%s>}",item->search.keyword ?: "");
+      g_variant_builder_add_parsed (&sub, "{'search.at-word-boundaries',<%b>}", item->search.at_word_boundaries);
+      g_variant_builder_add_parsed (&sub, "{'search.regex-enabled',<%b>}", item->search.regex_enabled);
+      g_variant_builder_add_parsed (&sub, "{'search.case-sensitive',<%b>}", item->search.case_sensitive);
 
       g_variant_builder_add (&builder,
-                             "(siii)",
+                             "(siiiv)",
                              item->uri,
                              item->column,
                              item->row,
-                             item->depth);
+                             item->depth,
+                             g_variant_new_variant (g_variant_builder_end (&sub)));
     }
 
   ide_task_return_pointer (task,
@@ -250,6 +272,7 @@ load_state_finish (IdeEditorSessionAddin *self,
       const Item *item = &g_array_index (state->items, Item, i);
       g_autoptr(GFile) file = NULL;
       IdeLayoutGridColumn *column;
+      IdeEditorSearch *search;
       IdeLayoutStack *stack;
       IdeEditorView *view;
       IdeBuffer *buffer;
@@ -270,6 +293,13 @@ load_state_finish (IdeEditorSessionAddin *self,
                            "visible", TRUE,
                            NULL);
 
+      search = ide_editor_view_get_search (view);
+
+      ide_editor_search_set_search_text (search, item->search.keyword);
+      ide_editor_search_set_at_word_boundaries (search, item->search.at_word_boundaries);
+      ide_editor_search_set_case_sensitive (search, item->search.case_sensitive);
+      ide_editor_search_set_regex_enabled (search, item->search.regex_enabled);
+
       gtk_container_add (GTK_CONTAINER (stack), GTK_WIDGET (view));
     }
 }
@@ -361,6 +391,18 @@ restore_file (GObject      *source,
     }
 }
 
+static void
+load_task_completed_cb (IdeTask              *task,
+                        GParamSpec           *pspec,
+                        IdeEditorPerspective *perspective)
+{
+  g_assert (IDE_IS_TASK (task));
+  g_assert (IDE_IS_EDITOR_PERSPECTIVE (perspective));
+
+  /* Always show the grid after the task completes */
+  _ide_editor_perspective_set_loading (perspective, FALSE);
+}
+
 static void
 ide_editor_session_addin_restore_async (IdeSessionAddin     *addin,
                                         GVariant            *state,
@@ -373,14 +415,28 @@ ide_editor_session_addin_restore_async (IdeSessionAddin     *addin,
   g_autoptr(GSettings) settings = NULL;
   const gchar *uri;
   LoadState *load_state;
+  IdeContext *context;
+  IdeWorkbench *workbench;
+  IdePerspective *editor;
   GVariantIter iter;
+  GVariant *extra = NULL;
+  const gchar *format = "(&siii)";
   gint column, row, depth;
 
   g_assert (IDE_IS_EDITOR_SESSION_ADDIN (addin));
   g_assert (!cancellable || G_IS_CANCELLABLE (cancellable));
 
+  context = ide_object_get_context (IDE_OBJECT (addin));
+  workbench = IDE_WORKBENCH (ide_context_get_workbench (context));
+  editor = ide_workbench_get_perspective_by_name (workbench, "editor");
+
   task = ide_task_new (addin, cancellable, callback, user_data);
   ide_task_set_source_tag (task, ide_editor_session_addin_restore_async);
+  g_signal_connect_object (task,
+                           "notify::completed",
+                           G_CALLBACK (load_task_completed_cb),
+                           editor,
+                           0);
 
   settings = g_settings_new ("org.gnome.builder");
 
@@ -401,10 +457,13 @@ ide_editor_session_addin_restore_async (IdeSessionAddin     *addin,
 
   load_state->active++;
 
-  while (g_variant_iter_next (&iter, "(&siii)", &uri, &column, &row, &depth))
+  if (g_variant_is_of_type (state, G_VARIANT_TYPE ("a(siiiv)")))
+    format = "(&siiiv)";
+
+  while (g_variant_iter_next (&iter, format, &uri, &column, &row, &depth, &extra))
     {
       g_autoptr(GFile) gfile = NULL;
-      Item item;
+      Item item = {0};
 
       IDE_TRACE_MSG ("Restore URI \"%s\" at %d:%d:%d", uri, column, row, depth);
 
@@ -412,30 +471,51 @@ ide_editor_session_addin_restore_async (IdeSessionAddin     *addin,
       item.column = column;
       item.row = row;
       item.depth = depth;
+
+      if (extra != NULL)
+        {
+          g_autoptr(GVariantDict) dict = NULL;
+
+          dict = g_variant_dict_new (g_variant_get_variant (extra));
+
+          g_variant_dict_lookup (dict, "search.keyword", "s", &item.search.keyword);
+          g_variant_dict_lookup (dict, "search.at-word-boundaries", "b", &item.search.at_word_boundaries);
+          g_variant_dict_lookup (dict, "search.case-sensitive", "b", &item.search.case_sensitive);
+          g_variant_dict_lookup (dict, "search.regex-enabled", "b", &item.search.regex_enabled);
+        }
+
       g_array_append_val (load_state->items, item);
 
       /* Skip loading buffer if already loading */
-      if (g_hash_table_contains (uris, uri))
-        continue;
+      if (!g_hash_table_contains (uris, uri))
+        {
+          g_hash_table_add (uris, g_strdup (uri));
+          gfile = g_file_new_for_uri (uri);
 
-      g_hash_table_add (uris, g_strdup (uri));
-      gfile = g_file_new_for_uri (uri);
+          load_state->active++;
 
-      load_state->active++;
+          g_file_query_info_async (gfile,
+                                   G_FILE_ATTRIBUTE_STANDARD_NAME,
+                                   G_FILE_QUERY_INFO_NONE,
+                                   G_PRIORITY_LOW,
+                                   cancellable,
+                                   restore_file,
+                                   g_object_ref (task));
+        }
 
-      g_file_query_info_async (gfile,
-                               G_FILE_ATTRIBUTE_STANDARD_NAME,
-                               G_FILE_QUERY_INFO_NONE,
-                               G_PRIORITY_LOW,
-                               cancellable,
-                               restore_file,
-                               g_object_ref (task));
+      g_clear_pointer (&extra, g_variant_unref);
     }
 
   load_state->active--;
 
   if (load_state->active == 0)
-    ide_task_return_boolean (task, TRUE);
+    {
+      ide_task_return_boolean (task, TRUE);
+      return;
+    }
+
+  /* Hide the grid until we've loaded */
+  _ide_editor_perspective_set_loading (IDE_EDITOR_PERSPECTIVE (editor), TRUE);
 }
 
 static gboolean
