@@ -171,7 +171,7 @@ ide_greeter_perspective_apply_filter_all (IdeGreeterPerspective *self)
 
   g_assert (IDE_IS_GREETER_PERSPECTIVE (self));
 
-  dzl_clear_pointer (&self->pattern_spec, dzl_pattern_spec_unref);
+  g_clear_pointer (&self->pattern_spec, dzl_pattern_spec_unref);
 
   if (NULL != (text = gtk_entry_get_text (GTK_ENTRY (self->search_entry))))
     self->pattern_spec = dzl_pattern_spec_new (text);
@@ -693,7 +693,7 @@ update_title_for_matching_addin (PeasExtensionSet *set,
 
       if (binding != NULL)
         {
-          dzl_clear_weak_pointer (&state->self->ready_binding);
+          g_clear_weak_pointer (&state->self->ready_binding);
           g_binding_unbind (binding);
         }
 
@@ -702,7 +702,7 @@ update_title_for_matching_addin (PeasExtensionSet *set,
                                         state->self->genesis_continue_button,
                                         "sensitive",
                                         G_BINDING_SYNC_CREATE);
-      dzl_set_weak_pointer (&state->self->ready_binding, binding);
+      g_set_weak_pointer (&state->self->ready_binding, binding);
 
       gtk_label_set_label (state->self->genesis_title, title);
       gtk_button_set_label (state->self->genesis_continue_button, next);
@@ -1254,8 +1254,8 @@ ide_greeter_perspective_finalize (GObject *object)
 {
   IdeGreeterPerspective *self = (IdeGreeterPerspective *)object;
 
-  dzl_clear_weak_pointer (&self->ready_binding);
-  dzl_clear_pointer (&self->pattern_spec, dzl_pattern_spec_unref);
+  g_clear_weak_pointer (&self->ready_binding);
+  g_clear_pointer (&self->pattern_spec, dzl_pattern_spec_unref);
   g_clear_object (&self->cancellable);
 
   G_OBJECT_CLASS (ide_greeter_perspective_parent_class)->finalize (object);
