@@ -1,6 +1,6 @@
 /* ide-layout-pane.c
  *
- * Copyright © 2015 Christian Hergert <christian@hergert.me>
+ * Copyright 2015 Christian Hergert <christian@hergert.me>
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -16,9 +16,12 @@
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
-#include <glib/gi18n.h>
+#define G_LOG_DOMAIN "ide-layout-pane"
 
-#include "dazzle.h"
+#include "config.h"
+
+#include <dazzle.h>
+#include <glib/gi18n.h>
 
 #include "layout/ide-layout-pane.h"
 
