@@ -18,7 +18,7 @@
 
 #pragma once
 
-#include <dazzle.h>
+#include <gtk/gtk.h>
 
 G_BEGIN_DECLS
 
