@@ -20,7 +20,6 @@
 
 #include "config.h"
 
-#include <dazzle.h>
 #include <glib/gi18n.h>
 
 #include "projects/ide-project-item.h"
@@ -144,7 +143,7 @@ ide_project_item_set_parent (IdeProjectItem *item,
   g_return_if_fail (IDE_IS_PROJECT_ITEM (item));
   g_return_if_fail (!parent || IDE_IS_PROJECT_ITEM (parent));
 
-  if (dzl_set_weak_pointer (&priv->parent, parent))
+  if (g_set_weak_pointer (&priv->parent, parent))
     g_object_notify_by_pspec (G_OBJECT (item), properties [PROP_PARENT]);
 }
 
@@ -154,8 +153,8 @@ ide_project_item_finalize (GObject *object)
   IdeProjectItem *self = (IdeProjectItem *)object;
   IdeProjectItemPrivate *priv = ide_project_item_get_instance_private (self);
 
-  dzl_clear_weak_pointer (&priv->parent);
-  dzl_clear_pointer (&priv->children, g_sequence_free);
+  g_clear_weak_pointer (&priv->parent);
+  g_clear_pointer (&priv->children, g_sequence_free);
 
   G_OBJECT_CLASS (ide_project_item_parent_class)->finalize (object);
 }
