@@ -66,7 +66,7 @@ static void
 prepare_state_free (PrepareState *state)
 {
   g_clear_object (&state->pipeline);
-  dzl_clear_pointer (&state->runtime_id, g_free);
+  g_clear_pointer (&state->runtime_id, g_free);
   g_slice_free (PrepareState, state);
 }
 
@@ -158,7 +158,7 @@ ide_runtime_manager_dispose (GObject *object)
   IdeRuntimeManager *self = (IdeRuntimeManager *)object;
 
   _ide_runtime_manager_unload (self);
-  dzl_clear_pointer (&self->runtimes, g_ptr_array_unref);
+  g_clear_pointer (&self->runtimes, g_ptr_array_unref);
 
   G_OBJECT_CLASS (ide_runtime_manager_parent_class)->dispose (object);
 }
@@ -356,7 +356,7 @@ _ide_runtime_manager_prepare_async (IdeRuntimeManager   *self,
   state = g_slice_new0 (PrepareState);
   state->runtime_id = g_strdup (runtime_id);
   state->pipeline = g_object_ref (pipeline);
-  ide_task_set_task_data (task, state, (GDestroyNotify)prepare_state_free);
+  ide_task_set_task_data (task, state, prepare_state_free);
 
   if (runtime_id == NULL)
     {
