@@ -124,7 +124,7 @@ delayed_activate_free (gpointer data)
   DelayedActivate *da = data;
 
   g_clear_object (&da->editor);
-  dzl_clear_pointer (&da->location, ide_source_location_unref);
+  g_clear_pointer (&da->location, ide_source_location_unref);
   g_slice_free (DelayedActivate, da);
 }
 
@@ -179,6 +179,10 @@ suggestion_activated (DzlSuggestionEntry *entry,
                                     g_steal_pointer (&da),
                                     delayed_activate_free);
     }
+
+  /* Chain up to properly clear entry buffer */
+  if (DZL_SUGGESTION_ENTRY_CLASS (ide_search_entry_parent_class)->suggestion_activated)
+    DZL_SUGGESTION_ENTRY_CLASS (ide_search_entry_parent_class)->suggestion_activated (entry, suggestion);
 }
 
 static void
