@@ -20,7 +20,6 @@
 
 #include "config.h"
 
-#include <dazzle.h>
 #include <errno.h>
 #include <glib/gi18n.h>
 #include <stdlib.h>
@@ -126,7 +125,7 @@ ide_snippet_parser_finish (IdeSnippetParser *parser)
   if (parser->cur_name)
     ide_snippet_parser_store(parser);
 
-  dzl_clear_pointer (&parser->cur_name, g_free);
+  g_clear_pointer (&parser->cur_name, g_free);
 
   g_string_truncate (parser->cur_text, 0);
   g_string_truncate (parser->snippet_text, 0);
