@@ -84,7 +84,7 @@ ide_cursor_dispose (GObject *object)
       if (self->highlight_tag != NULL)
         gtk_text_tag_table_remove (gtk_text_buffer_get_tag_table (buffer),
                                    self->highlight_tag);
-      dzl_clear_weak_pointer (&self->source_view);
+      g_clear_weak_pointer (&self->source_view);
     }
 
   if (self->operations_signals != NULL)
@@ -115,7 +115,7 @@ ide_cursor_dispose (GObject *object)
 
     }
 
-  dzl_clear_pointer (&self->cursors, g_list_free);
+  g_clear_pointer (&self->cursors, g_list_free);
 
   G_OBJECT_CLASS (ide_cursor_parent_class)->dispose (object);
 }
@@ -221,7 +221,7 @@ ide_cursor_remove_cursors (IdeCursor *self)
           g_slice_free (VirtualCursor, vc);
         }
 
-      dzl_clear_pointer (&self->cursors, g_list_free);
+      g_clear_pointer (&self->cursors, g_list_free);
     }
 }
 
@@ -772,7 +772,7 @@ ide_cursor_set_property (GObject      *object,
   switch (prop_id)
     {
     case PROP_IDE_SOURCE_VIEW:
-      dzl_set_weak_pointer (&self->source_view, g_value_get_object (value));
+      g_set_weak_pointer (&self->source_view, g_value_get_object (value));
       break;
 
     default:
