@@ -20,8 +20,6 @@
 
 #include "config.h"
 
-#include <dazzle.h>
-
 #include "ide-context.h"
 
 #include "buffers/ide-buffer.h"
@@ -91,7 +89,7 @@ disconnect_buffer (IdeLineChangeGutterRenderer *self)
     {
       g_signal_handler_disconnect (self->buffer, self->buffer_notify_style_scheme);
       self->buffer_notify_style_scheme = 0;
-      dzl_clear_weak_pointer (&self->buffer);
+      g_clear_weak_pointer (&self->buffer);
     }
 }
 
@@ -104,7 +102,7 @@ disconnect_view (IdeLineChangeGutterRenderer *self)
     {
       g_signal_handler_disconnect (self->text_view, self->text_view_notify_buffer);
       self->text_view_notify_buffer = 0;
-      dzl_clear_weak_pointer (&self->text_view);
+      g_clear_weak_pointer (&self->text_view);
     }
 }
 
@@ -195,7 +193,7 @@ connect_buffer (IdeLineChangeGutterRenderer *self)
 
   if (buffer)
     {
-      dzl_set_weak_pointer (&self->buffer, buffer);
+      g_set_weak_pointer (&self->buffer, buffer);
       self->buffer_notify_style_scheme = g_signal_connect (buffer,
                                                            "notify::style-scheme",
                                                            G_CALLBACK (notify_style_scheme_cb),
@@ -222,7 +220,7 @@ connect_view (IdeLineChangeGutterRenderer *self)
 
   if (view)
     {
-      dzl_set_weak_pointer (&self->text_view, view);
+      g_set_weak_pointer (&self->text_view, view);
       self->text_view_notify_buffer = g_signal_connect (self->text_view,
                                                         "notify::buffer",
                                                         G_CALLBACK (notify_buffer_cb),
