@@ -340,7 +340,7 @@ G_LOCK_DEFINE (global_task_list);
 static void
 ide_task_cancel_free (IdeTaskCancel *cancel)
 {
-  dzl_clear_pointer (&cancel->main_context, g_main_context_unref);
+  g_clear_pointer (&cancel->main_context, g_main_context_unref);
   g_clear_object (&cancel->task);
   g_slice_free (IdeTaskCancel, cancel);
 }
@@ -466,7 +466,7 @@ ide_task_result_free (IdeTaskResult *result)
     }
 
   g_clear_object (&result->task);
-  dzl_clear_pointer (&result->main_context, g_main_context_unref);
+  g_clear_pointer (&result->main_context, g_main_context_unref);
   g_slice_free (IdeTaskResult, result);
 }
 
@@ -565,7 +565,6 @@ ide_task_thread_func (gpointer data)
 
   g_assert (source_object == NULL);
   g_assert (cancellable == NULL);
-  g_assert (task == NULL);
 }
 
 static void
@@ -579,7 +578,7 @@ ide_task_dispose (GObject *object)
   ide_task_release (self, TRUE);
 
   g_mutex_lock (&priv->mutex);
-  dzl_clear_pointer (&priv->result, ide_task_result_free);
+  g_clear_pointer (&priv->result, ide_task_result_free);
   g_mutex_unlock (&priv->mutex);
 
   G_OBJECT_CLASS (ide_task_parent_class)->dispose (object);
@@ -619,7 +618,7 @@ ide_task_finalize (GObject *object)
   g_assert (priv->chained == NULL);
   g_assert (priv->thread_result == NULL);
 
-  dzl_clear_pointer (&priv->main_context, g_main_context_unref);
+  g_clear_pointer (&priv->main_context, g_main_context_unref);
   g_clear_object (&priv->cancellable);
   g_mutex_clear (&priv->mutex);
 
@@ -1046,6 +1045,12 @@ ide_task_return_cb (gpointer user_data)
   return G_SOURCE_REMOVE;
 }
 
+static gboolean
+ide_task_return_dummy_cb (gpointer data)
+{
+  return G_SOURCE_REMOVE;
+}
+
 static void
 ide_task_return (IdeTask       *self,
                  IdeTaskResult *result)
@@ -1067,6 +1072,8 @@ ide_task_return (IdeTask       *self,
 
   if (priv->return_called)
     {
+      GSource *source;
+
       if (result->type == IDE_TASK_RESULT_CANCELLED)
         {
           /* We already had a result, and now raced to be notified of
@@ -1077,21 +1084,28 @@ ide_task_return (IdeTask       *self,
           return;
         }
 
-      /*
-       * We already failed this task, but we need to ensure that the data
-       * is released from the main context rather than potentially on a
-       * thread (as we could be now).
-       *
-       * Since this can only happen when return_on_cancel is set, we can
-       * be assured the main context is alive because that is our contract
-       * with the API consumer.
+      /* If we haven't been cancelled, then we reached this path multiple
+       * times by programmer error.
        */
       if (!priv->got_cancel)
-        {
-          /* leak result to ensure we don't free anything in the wrong context */
-          g_critical ("Attempted to set task result multiple times, leaking result");
-          return;
-        }
+        g_critical ("Attempted to set result on task [%s] multiple times", priv->name);
+
+      /*
+       * This task has already returned, but we need to ensure that we pass
+       * the data back to the main context so that it is freed appropriately.
+       */
+
+      source = g_idle_source_new ();
+      g_source_set_name (source, "[ide-task] finalize task result");
+      g_source_set_ready_time (source, -1);
+      g_source_set_callback (source,
+                             ide_task_return_dummy_cb,
+                             result,
+                             (GDestroyNotify)ide_task_result_free);
+      g_source_attach (source, priv->main_context);
+      g_source_unref (source);
+
+      return;
     }
 
   priv->return_called = TRUE;
@@ -1792,9 +1806,9 @@ ide_task_set_task_data_cb (gpointer data)
 }
 
 void
-ide_task_set_task_data (IdeTask        *self,
-                        gpointer        task_data,
-                        GDestroyNotify  task_data_destroy)
+(ide_task_set_task_data) (IdeTask        *self,
+                          gpointer        task_data,
+                          GDestroyNotify  task_data_destroy)
 {
   IdeTaskPrivate *priv = ide_task_get_instance_private (self);
   g_autoptr(IdeTaskData) old_task_data = NULL;
