@@ -20,7 +20,6 @@
 
 #include "config.h"
 
-#include <dazzle.h>
 #include <glib/gi18n.h>
 
 #include "ide-debug.h"
@@ -199,8 +198,8 @@ ide_pkcon_transfer_finalize (GObject *object)
 {
   IdePkconTransfer *self = (IdePkconTransfer *)object;
 
-  dzl_clear_pointer (&self->packages, g_strfreev);
-  dzl_clear_pointer (&self->status, g_free);
+  g_clear_pointer (&self->packages, g_strfreev);
+  g_clear_pointer (&self->status, g_free);
 
   G_OBJECT_CLASS (ide_pkcon_transfer_parent_class)->finalize (object);
 }
