@@ -1,6 +1,6 @@
 /* ide-transfers-progress-icon.h
  *
- * Copyright © 2016 Christian Hergert <chergert@redhat.com>
+ * Copyright 2016 Christian Hergert <chergert@redhat.com>
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -20,14 +20,20 @@
 
 #include <gtk/gtk.h>
 
+#include "ide-version-macros.h"
+
 G_BEGIN_DECLS
 
 #define IDE_TYPE_TRANSFERS_PROGRESS_ICON (ide_transfers_progress_icon_get_type())
 
+IDE_AVAILABLE_IN_ALL
 G_DECLARE_FINAL_TYPE (IdeTransfersProgressIcon, ide_transfers_progress_icon, IDE, TRANSFERS_PROGRESS_ICON, GtkDrawingArea)
 
+IDE_AVAILABLE_IN_ALL
 GtkWidget *ide_transfers_progress_icon_new          (void);
+IDE_AVAILABLE_IN_ALL
 gdouble    ide_transfers_progress_icon_get_progress (IdeTransfersProgressIcon *self);
+IDE_AVAILABLE_IN_ALL
 void       ide_transfers_progress_icon_set_progress (IdeTransfersProgressIcon *self,
                                                      gdouble                   progress);
 
