@@ -18,7 +18,6 @@
 
 #define G_LOG_DOMAIN "ide-glib"
 
-#include <dazzle.h>
 #include <string.h>
 
 #include "config.h"
@@ -323,6 +322,8 @@ ide_g_file_get_children_worker (IdeTask      *task,
       g_ptr_array_add (children, g_steal_pointer (&file_info));
     }
 
+  g_file_enumerator_close (enumerator, NULL, NULL);
+
   ide_task_return_pointer (task,
                            g_steal_pointer (&children),
                            (GDestroyNotify) g_ptr_array_unref);
@@ -420,7 +421,7 @@ typedef struct
 static void
 find_free (Find *f)
 {
-  dzl_clear_pointer (&f->spec, g_pattern_spec_free);
+  g_clear_pointer (&f->spec, g_pattern_spec_free);
   g_slice_free (Find, f);
 }
 
@@ -554,7 +555,7 @@ ide_g_file_find_with_depth_async (GFile               *file,
   f = g_slice_new0 (Find);
   f->spec = g_pattern_spec_new (pattern);
   f->depth = depth;
-  ide_task_set_task_data (task, f, (GDestroyNotify)find_free);
+  ide_task_set_task_data (task, f, find_free);
 
   if (f->spec == NULL)
     {
