@@ -1,6 +1,6 @@
 /* ide-vcs-config.c
  *
- * Copyright © 2016 Akshaya Kakkilaya <akshaya.kakkilaya@gmail.com>
+ * Copyright 2016 Akshaya Kakkilaya <akshaya.kakkilaya@gmail.com>
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -16,6 +16,10 @@
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
+#define G_LOG_DOMAIN "ide-vcs-config"
+
+#include "config.h"
+
 #include "vcs/ide-vcs-config.h"
 
 G_DEFINE_INTERFACE (IdeVcsConfig, ide_vcs_config, G_TYPE_OBJECT)
