@@ -1,6 +1,6 @@
 /* ide-vcs-file-info.h
  *
- * Copyright © 2017 Christian Hergert <chergert@redhat.com>
+ * Copyright 2017 Christian Hergert <chergert@redhat.com>
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -20,10 +20,13 @@
 
 #include <gio/gio.h>
 
+#include "ide-version-macros.h"
+
 G_BEGIN_DECLS
 
 #define IDE_TYPE_VCS_FILE_INFO (ide_vcs_file_info_get_type())
 
+IDE_AVAILABLE_IN_ALL
 G_DECLARE_DERIVABLE_TYPE (IdeVcsFileInfo, ide_vcs_file_info, IDE, VCS_FILE_INFO, GObject)
 
 typedef enum
@@ -42,12 +45,16 @@ struct _IdeVcsFileInfoClass
   GObjectClass parent_class;
 
   /*< private >*/
-  gpointer padding[16];
+  gpointer _reserved[16];
 };
 
+IDE_AVAILABLE_IN_ALL
 IdeVcsFileInfo   *ide_vcs_file_info_new        (GFile            *file);
+IDE_AVAILABLE_IN_ALL
 GFile            *ide_vcs_file_info_get_file   (IdeVcsFileInfo   *self);
+IDE_AVAILABLE_IN_ALL
 IdeVcsFileStatus  ide_vcs_file_info_get_status (IdeVcsFileInfo   *self);
+IDE_AVAILABLE_IN_ALL
 void              ide_vcs_file_info_set_status (IdeVcsFileInfo   *self,
                                                 IdeVcsFileStatus  status);
 
