@@ -75,6 +75,9 @@ ide_workbench_notify_visible_child (IdeWorkbench *self,
   g_assert (IDE_IS_WORKBENCH (self));
   g_assert (GTK_IS_STACK (stack));
 
+  if (self->unloading)
+    return;
+
   perspective = gtk_stack_get_visible_child (stack);
 
   if (perspective != NULL)
@@ -107,9 +110,18 @@ ide_workbench_unload_cb (GObject      *object,
   if (!ide_context_unload_finish (context, result, &error))
     g_warning ("Failed to unload context: %s", error->message);
 
+  /* Now that we've unloaded, release the addins too. */
+  g_clear_object (&self->addins);
+
   gtk_widget_destroy (GTK_WIDGET (self));
 
   g_clear_object (&self->context);
+
+#ifdef IDE_ENABLE_TRACE
+  /* Flush out any pending work */
+  while (gtk_events_pending ())
+    gtk_main_iteration ();
+#endif
 }
 
 static gboolean
@@ -188,11 +200,10 @@ ide_workbench_delete_event (GtkWidget   *widget,
    */
   gtk_widget_hide (GTK_WIDGET (self));
 
-  /*
-   * Now start unloading addins, which will cascade into the removal
-   * of perspectives and other bits and pieces (like editor addins).
-   */
-  g_clear_object (&self->addins);
+  dzl_gtk_widget_mux_action_groups (GTK_WIDGET (self), NULL, "IDE_PERSPECTIVE_ACTIONS");
+  gtk_widget_insert_action_group (GTK_WIDGET (self), "build-manager", NULL);
+  gtk_widget_insert_action_group (GTK_WIDGET (self), "run-manager", NULL);
+  gtk_widget_insert_action_group (GTK_WIDGET (self), "device-manager", NULL);
 
   if (self->context != NULL)
     {
@@ -204,6 +215,12 @@ ide_workbench_delete_event (GtkWidget   *widget,
       return GDK_EVENT_STOP;
     }
 
+  /*
+   * Now start unloading addins, which will cascade into the removal
+   * of perspectives and other bits and pieces (like editor addins).
+   */
+  g_clear_object (&self->addins);
+
   return GDK_EVENT_PROPAGATE;
 }
 
@@ -667,8 +684,13 @@ ide_workbench_set_context (IdeWorkbench *self,
   g_return_if_fail (IDE_IS_CONTEXT (context));
   g_return_if_fail (self->context == NULL);
 
+  if (self->unloading)
+    IDE_EXIT;
+
   g_set_object (&self->context, context);
 
+  _ide_context_set_workbench (context, GTK_WIDGET (self));
+
   project = ide_context_get_project (context);
   g_object_bind_property_full (project, "name",
                                self, "title",
