@@ -19,7 +19,6 @@
 #include <libpeas/peas.h>
 #include <ide.h>
 
-#include "ide-autotools-application-addin.h"
 #include "ide-autotools-build-system.h"
 #include "ide-autotools-build-target-provider.h"
 #include "ide-autotools-pipeline-addin.h"
@@ -27,7 +26,6 @@
 void
 ide_autotools_register_types (PeasObjectModule *module)
 {
-  peas_object_module_register_extension_type (module, IDE_TYPE_APPLICATION_ADDIN, IDE_TYPE_AUTOTOOLS_APPLICATION_ADDIN);
   peas_object_module_register_extension_type (module, IDE_TYPE_BUILD_PIPELINE_ADDIN, IDE_TYPE_AUTOTOOLS_PIPELINE_ADDIN);
   peas_object_module_register_extension_type (module, IDE_TYPE_BUILD_SYSTEM, IDE_TYPE_AUTOTOOLS_BUILD_SYSTEM);
   peas_object_module_register_extension_type (module, IDE_TYPE_BUILD_TARGET_PROVIDER, IDE_TYPE_AUTOTOOLS_BUILD_TARGET_PROVIDER);
