@@ -56,8 +56,10 @@ typedef struct
   gulong          cancel_id;
 } Call;
 
+static void service_iface_init (IdeServiceInterface *iface);
+
 G_DEFINE_TYPE_EXTENDED (IdeClangClient, ide_clang_client, IDE_TYPE_OBJECT, 0,
-                        G_IMPLEMENT_INTERFACE (IDE_TYPE_SERVICE, NULL))
+                        G_IMPLEMENT_INTERFACE (IDE_TYPE_SERVICE, service_iface_init))
 
 static void
 call_free (gpointer data)
@@ -69,9 +71,9 @@ call_free (gpointer data)
 
   c->cancel_id = 0;
 
-  dzl_clear_pointer (&c->method, g_free);
-  dzl_clear_pointer (&c->params, g_variant_unref);
-  dzl_clear_pointer (&c->id, g_variant_unref);
+  g_clear_pointer (&c->method, g_free);
+  g_clear_pointer (&c->params, g_variant_unref);
+  g_clear_pointer (&c->id, g_variant_unref);
   g_clear_object (&c->cancellable);
   g_clear_object (&c->self);
   g_slice_free (Call, c);
@@ -157,7 +159,7 @@ ide_clang_client_subprocess_exited (IdeClangClient          *self,
     self->state = STATE_SPAWNING;
 
   g_clear_object (&self->rpc_client);
-  dzl_clear_pointer (&self->seq_by_file, g_hash_table_unref);
+  g_clear_pointer (&self->seq_by_file, g_hash_table_unref);
 
   IDE_EXIT;
 }
@@ -384,6 +386,9 @@ ide_clang_client_dispose (GObject *object)
 
   self->state = STATE_SHUTDOWN;
 
+  if (self->seq_by_file != NULL)
+    g_hash_table_remove_all (self->seq_by_file);
+
   if (self->supervisor != NULL)
     {
       g_autoptr(IdeSubprocessSupervisor) supervisor = g_steal_pointer (&self->supervisor);
@@ -419,7 +424,7 @@ ide_clang_client_finalize (GObject *object)
 {
   IdeClangClient *self = (IdeClangClient *)object;
 
-  dzl_clear_pointer (&self->seq_by_file, g_hash_table_unref);
+  g_clear_pointer (&self->seq_by_file, g_hash_table_unref);
   g_clear_object (&self->rpc_client);
   g_clear_object (&self->root_uri);
   g_clear_object (&self->supervisor);
@@ -1085,6 +1090,8 @@ ide_clang_client_diagnose_cb (GObject      *object,
 
       if (diag != NULL)
         ide_diagnostics_take (ret, g_steal_pointer (&diag));
+
+      g_variant_unref (v);
     }
 
   ide_task_return_pointer (task,
@@ -1391,3 +1398,17 @@ ide_clang_client_set_buffer_finish (IdeClangClient  *self,
 
   return ide_task_propagate_boolean (IDE_TASK (result), error);
 }
+
+static void
+ide_clang_client_stop (IdeService *service)
+{
+  g_assert (IDE_IS_CLANG_CLIENT (service));
+
+  g_object_run_dispose (G_OBJECT (service));
+}
+
+static void
+service_iface_init (IdeServiceInterface *iface)
+{
+  iface->stop = ide_clang_client_stop;
+}
