@@ -1,6 +1,7 @@
 /* ide-clang-code-index-entries.h
  *
  * Copyright 2017 Anoop Chandu <anoopchandu96@gmail.com>
+ * Copyright 2018 Christian Hergert <chergert@redhat.com>
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -18,7 +19,6 @@
 
 #pragma once
 
-#include <clang-c/Index.h>
 #include <ide.h>
 
 G_BEGIN_DECLS
@@ -27,8 +27,7 @@ G_BEGIN_DECLS
 
 G_DECLARE_FINAL_TYPE (IdeClangCodeIndexEntries, ide_clang_code_index_entries, IDE, CLANG_CODE_INDEX_ENTRIES, GObject)
 
-IdeClangCodeIndexEntries *ide_clang_code_index_entries_new (CXIndex            index,
-                                                            CXTranslationUnit  unit,
-                                                            const gchar       *source_filename);
+IdeCodeIndexEntries *ide_clang_code_index_entries_new (const gchar *path,
+                                                       GVariant    *entries);
 
 G_END_DECLS
