@@ -65,7 +65,7 @@ gbp_cmake_build_target_finalize (GObject *object)
   GbpCMakeBuildTarget *self = (GbpCMakeBuildTarget *)object;
 
   g_clear_object (&self->install_directory);
-  dzl_clear_pointer (&self->name, g_free);
+  g_clear_pointer (&self->name, g_free);
 
   G_OBJECT_CLASS (gbp_cmake_build_target_parent_class)->finalize (object);
 }
