@@ -119,22 +119,22 @@ build_data_free (BuildData *self)
   g_clear_object (&self->index_dir);
   g_clear_object (&self->building_data_dir);
   g_clear_object (&self->building_index_dir);
-  dzl_clear_pointer (&self->changes, g_ptr_array_unref);
+  g_clear_pointer (&self->changes, g_ptr_array_unref);
   g_slice_free (BuildData, self);
 }
 
 static void
 indexer_info_free (IndexerInfo *info)
 {
-  dzl_clear_pointer (&info->specs, g_ptr_array_unref);
-  dzl_clear_pointer (&info->mime_types, g_ptr_array_unref);
+  g_clear_pointer (&info->specs, g_ptr_array_unref);
+  g_clear_pointer (&info->mime_types, g_ptr_array_unref);
   g_slice_free (IndexerInfo, info);
 }
 
 static void
 get_changes_data_free (GetChangesData *self)
 {
-  dzl_clear_pointer (&self->indexers, indexer_info_free);
+  g_clear_pointer (&self->indexers, indexer_info_free);
   g_clear_object (&self->data_dir);
   g_clear_object (&self->index_dir);
   g_clear_object (&self->vcs);
@@ -155,7 +155,7 @@ add_entries_data_free (AddEntriesData *self)
 static void
 file_info_free (FileInfo *file_info)
 {
-  dzl_clear_pointer (&file_info->name, g_free);
+  g_clear_pointer (&file_info->name, g_free);
   g_clear_object (&file_info->directory);
   g_slice_free (FileInfo, file_info);
 }
@@ -415,7 +415,7 @@ get_index_dir (GFile *index_root,
   if (relative != NULL)
     return g_file_get_child (index_root, relative);
   else
-    return g_object_ref (index_root);
+    return g_file_dup (index_root);
 }
 
 static void
@@ -437,7 +437,6 @@ remove_indexes_in_dir (GFile        *index_dir,
 
 static gboolean
 directory_needs_update (GFile        *index_dir,
-                        GFile        *directory,
                         GQueue       *file_infos,
                         GCancellable *cancellable)
 {
@@ -448,7 +447,6 @@ directory_needs_update (GFile        *index_dir,
   guint n_files;
 
   g_assert (G_IS_FILE (index_dir));
-  g_assert (G_IS_FILE (directory));
   g_assert (file_infos != NULL);
   g_assert (!cancellable || G_IS_CANCELLABLE (cancellable));
 
@@ -526,10 +524,10 @@ filter_ignored (IdeVcs            *vcs,
         {
           GList *tmp = iter->next;
           g_queue_delete_link (file_infos, iter);
+          file_info_free (info);
           if (tmp == NULL)
             break;
           iter = tmp;
-          file_info_free (info);
           goto again;
         }
     }
@@ -585,7 +583,7 @@ find_all_files_typed (GFile        *root,
 
           fi = g_slice_new0 (FileInfo);
           fi->magic = FILE_INFO_MAGIC;
-          fi->directory = g_object_ref (root);
+          fi->directory = g_file_dup (root);
           fi->name = g_strdup (g_file_info_get_name (info));
           fi->file_type = g_file_info_get_file_type (info);
           fi->content_type = g_intern_string (g_file_info_get_content_type (info));
@@ -661,7 +659,7 @@ get_changes_worker (IdeTask      *task,
   g_assert (IDE_IS_VCS (gcd->vcs));
 
   if (ide_task_return_error_if_cancelled (task))
-    return;
+    goto cancelled;
 
   /*
    * If we are recursive, collect all the directories we need to look
@@ -682,7 +680,7 @@ get_changes_worker (IdeTask      *task,
   to_update = g_ptr_array_new_with_free_func (g_object_unref);
 
   if (ide_task_return_error_if_cancelled (task))
-    return;
+    goto cancelled;
 
   /*
    * Process directories to check for changes, while ensuring we have not
@@ -707,22 +705,24 @@ get_changes_worker (IdeTask      *task,
       filter_ignored (gcd->vcs, &files, gcd->indexers);
 
       if (!(relative = g_file_get_relative_path (gcd->index_dir, dir)))
-        index_dir = g_object_ref (gcd->index_dir);
+        index_dir = g_file_dup (gcd->index_dir);
       else
         index_dir = g_file_get_child (gcd->index_dir, relative);
 
       if (files.length == 0)
         remove_indexes_in_dir (index_dir, cancellable);
-      else if (directory_needs_update (index_dir, dir, &files, cancellable))
-        g_ptr_array_add (to_update, g_steal_pointer (&dir));
+      else if (directory_needs_update (index_dir, &files, cancellable))
+        g_ptr_array_add (to_update, g_file_dup (dir));
 
       g_queue_foreach (&files, (GFunc)file_info_free, NULL);
       g_queue_clear (&files);
 
       if (ide_task_return_error_if_cancelled (task))
-        return;
+        break;
     }
 
+cancelled:
+
   /* In case we were cancelled */
   if (gcd->directories.length > 0)
     {
@@ -731,13 +731,17 @@ get_changes_worker (IdeTask      *task,
     }
 
   g_assert (gcd->directories.length == 0);
-  g_assert (IDE_IS_VCS (gcd->vcs));
-  g_assert (G_IS_FILE (gcd->data_dir));
-  g_assert (G_IS_FILE (gcd->index_dir));
 
-  ide_task_return_pointer (task,
-                           g_steal_pointer (&to_update),
-                           (GDestroyNotify) g_ptr_array_unref);
+  if (!ide_task_had_error (task))
+    {
+      g_assert (IDE_IS_VCS (gcd->vcs));
+      g_assert (G_IS_FILE (gcd->data_dir));
+      g_assert (G_IS_FILE (gcd->index_dir));
+
+      ide_task_return_pointer (task,
+                               g_steal_pointer (&to_update),
+                               (GDestroyNotify)g_ptr_array_unref);
+    }
 }
 
 /*
@@ -784,13 +788,13 @@ get_changes_async (IdeCodeIndexBuilder *self,
   gcd = g_slice_new0 (GetChangesData);
   gcd->magic = GET_CHANGES_MAGIC;
   gcd->indexers = collect_indexer_info ();
-  gcd->data_dir = g_object_ref (data_dir);
-  gcd->index_dir = g_object_ref (index_dir);
+  gcd->data_dir = g_file_dup (data_dir);
+  gcd->index_dir = g_file_dup (index_dir);
   gcd->recursive = !!recursive;
   gcd->vcs = g_object_ref (vcs);
-  ide_task_set_task_data (task, gcd, (GDestroyNotify)get_changes_data_free);
+  ide_task_set_task_data (task, gcd, get_changes_data_free);
 
-  g_queue_push_head (&gcd->directories, g_object_ref (data_dir));
+  g_queue_push_head (&gcd->directories, g_file_dup (data_dir));
 
   ide_task_run_in_thread (task, get_changes_worker);
 }
@@ -1025,7 +1029,7 @@ add_entries_to_index_async (IdeCodeIndexBuilder     *self,
   task_data->map_builder = g_object_ref (map_builder);
   task_data->fuzzy_builder = g_object_ref (fuzzy_builder);
   task_data->file_id = file_id;
-  ide_task_set_task_data (task, task_data, (GDestroyNotify)add_entries_data_free);
+  ide_task_set_task_data (task, task_data, add_entries_data_free);
 
   ide_code_index_entries_next_entries_async (entries,
                                              cancellable,
@@ -1169,10 +1173,10 @@ index_directory_async (IdeCodeIndexBuilder *self,
 
   idd = g_slice_new0 (IndexDirectoryData);
   idd->magic = INDEX_DIRECTORY_MAGIC;
-  idd->index_dir = g_object_ref (index_dir);
+  idd->index_dir = g_file_dup (index_dir);
   idd->fuzzy = dzl_fuzzy_index_builder_new ();
   idd->map = ide_persistent_map_builder_new ();
-  ide_task_set_task_data (task, idd, (GDestroyNotify)index_directory_data_free);
+  ide_task_set_task_data (task, idd, index_directory_data_free);
 
   g_hash_table_iter_init (&iter, build_flags);
 
@@ -1285,8 +1289,7 @@ build_get_build_flags_cb (GObject      *object,
   g_assert (bd->changes->len > 0);
   g_assert (IDE_IS_BUILD_SYSTEM (bd->build_system));
 
-  data_dir = g_object_ref (g_ptr_array_index (bd->changes, bd->changes->len - 1));
-  g_ptr_array_remove_index (bd->changes, bd->changes->len - 1);
+  data_dir = g_ptr_array_steal_index (bd->changes, bd->changes->len - 1);
   g_assert (G_IS_FILE (data_dir));
 
   if (!(flags = ide_build_system_get_build_flags_for_dir_finish (build_system, result, &error)))
@@ -1344,6 +1347,7 @@ build_tick (IdeTask *task)
   g_assert (G_IS_FILE (bd->data_dir));
   g_assert (G_IS_FILE (bd->index_dir));
   g_assert (IDE_IS_BUILD_SYSTEM (bd->build_system));
+  g_assert (bd->changes != NULL);
 
   if (bd->changes->len == 0)
     {
@@ -1388,6 +1392,7 @@ build_get_changes_cb (GObject      *object,
   g_assert (IDE_IS_BUILD_SYSTEM (bd->build_system));
 
   bd->changes = get_changes_finish (self, result, &error);
+  IDE_PTR_ARRAY_SET_FREE_FUNC (bd->changes, g_object_unref);
 
   if (bd->changes == NULL)
     ide_task_return_error (task, g_steal_pointer (&error));
@@ -1431,10 +1436,10 @@ ide_code_index_builder_build_async (IdeCodeIndexBuilder *self,
 
   bd = g_slice_new0 (BuildData);
   bd->magic = BUILD_DATA_MAGIC;
-  bd->data_dir = g_object_ref (directory);
+  bd->data_dir = g_file_dup (directory);
   bd->index_dir = g_steal_pointer (&index_dir);
   bd->build_system = g_object_ref (build_system);
-  ide_task_set_task_data (task, bd, (GDestroyNotify)build_data_free);
+  ide_task_set_task_data (task, bd, build_data_free);
 
   get_changes_async (self,
                      bd->data_dir,
