@@ -85,7 +85,7 @@ gb_command_bar_load (IdeWorkbenchAddin *addin,
 
   g_assert (GB_IS_COMMAND_BAR (self));
 
-  dzl_set_weak_pointer (&self->workbench, workbench);
+  g_set_weak_pointer (&self->workbench, workbench);
 
   provider = g_object_new (GB_TYPE_COMMAND_GACTION_PROVIDER,
                            "workbench", self->workbench,
@@ -123,7 +123,7 @@ gb_command_bar_unload (IdeWorkbenchAddin *addin,
    */
 
   g_action_map_remove_action (G_ACTION_MAP (workbench), "show-command-bar");
-  dzl_clear_weak_pointer (&self->workbench);
+  g_clear_weak_pointer (&self->workbench);
 }
 
 GtkWidget *
@@ -198,7 +198,7 @@ gb_command_bar_set_last_focus (GbCommandBar *self,
   g_return_if_fail (GB_IS_COMMAND_BAR (self));
   g_return_if_fail (!widget || GTK_IS_WIDGET (widget));
 
-  dzl_set_weak_pointer (&self->last_focus, widget);
+  g_set_weak_pointer (&self->last_focus, widget);
 }
 
 /**
@@ -222,7 +222,7 @@ gb_command_bar_show (GbCommandBar *self)
   gtk_widget_hide (GTK_WIDGET (self->completion_scroller));
 
   self->history_current = NULL;
-  dzl_clear_pointer (&self->saved_text, g_free);
+  g_clear_pointer (&self->saved_text, g_free);
   self->saved_position_valid = FALSE;
 
   gtk_entry_set_text (self->entry, "");
@@ -390,7 +390,7 @@ gb_command_bar_complete (GbCommandBar *self)
     }
   else
     {
-      dzl_clear_pointer (&self->last_completion, g_free);
+      g_clear_pointer (&self->last_completion, g_free);
 
       completions = gb_command_manager_complete (self->command_manager, current_prefix);
 
@@ -506,7 +506,7 @@ gb_command_bar_move_history (GbCommandBar     *self,
 
   if (self->history_current == NULL)
     {
-      dzl_clear_pointer (&self->saved_text, g_free);
+      g_clear_pointer (&self->saved_text, g_free);
       self->saved_text = g_strdup (gtk_entry_get_text (self->entry));
     }
   self->history_current = l;
@@ -629,12 +629,12 @@ gb_command_bar_finalize (GObject *object)
 {
   GbCommandBar *self = (GbCommandBar *)object;
 
-  dzl_clear_weak_pointer (&self->workbench);
+  g_clear_weak_pointer (&self->workbench);
 
-  dzl_clear_pointer (&self->last_completion, g_free);
-  dzl_clear_pointer (&self->saved_text, g_free);
+  g_clear_pointer (&self->last_completion, g_free);
+  g_clear_pointer (&self->saved_text, g_free);
   g_queue_free_full (self->history, g_free);
-  dzl_clear_weak_pointer (&self->last_focus);
+  g_clear_weak_pointer (&self->last_focus);
 
   G_OBJECT_CLASS (gb_command_bar_parent_class)->finalize (object);
 }
