@@ -24,13 +24,10 @@ G_BEGIN_DECLS
 
 struct _IdeCtagsCompletionProvider
 {
-  IdeObject             parent_instance;
-  gint                  minimum_word_size;
-  GSettings            *settings;
-  GPtrArray            *indexes;
-  IdeCompletionResults *results;
-  gchar                *current_word;
-  IdeSourceView        *view;
+  IdeObject  parent_instance;
+  GSettings *settings;
+  GPtrArray *indexes;
+  guint      enabled : 1;
 };
 
 G_END_DECLS
