@@ -49,8 +49,8 @@ deploy_state_free (DeployState *state)
 {
   g_clear_object (&state->pipeline);
   g_clear_object (&state->device);
-  dzl_clear_pointer (&state->app_id, g_free);
-  dzl_clear_pointer (&state->flatpak_path, g_free);
+  g_clear_pointer (&state->app_id, g_free);
+  g_clear_pointer (&state->flatpak_path, g_free);
   if (state->progress_data_destroy)
     state->progress_data_destroy (state->progress_data);
   g_slice_free (DeployState, state);
@@ -341,7 +341,7 @@ gbp_deviced_deploy_strategy_deploy_async (IdeDeployStrategy     *strategy,
   state->progress = progress;
   state->progress_data = progress_data;
   state->progress_data_destroy = progress_data_destroy;
-  ide_task_set_task_data (task, state, (GDestroyNotify)deploy_state_free);
+  ide_task_set_task_data (task, state, deploy_state_free);
 
   /*
    * First make sure we've built up to the point where we have a
