@@ -457,9 +457,12 @@ gbp_flatpak_manifest_initable_init (GInitable     *initable,
   self->root = json_node_ref (root);
   self->primary = json_object_ref (primary);
 
+  if (!validate_properties (self, error))
+    return FALSE;
+
   ide_configuration_set_dirty (IDE_CONFIGURATION (self), FALSE);
 
-  return validate_properties (self, error);
+  return TRUE;
 }
 
 static void
@@ -554,19 +557,19 @@ gbp_flatpak_manifest_finalize (GObject *object)
   g_clear_object (&self->file);
   g_clear_object (&self->file_monitor);
 
-  dzl_clear_pointer (&self->root, json_node_unref);
+  g_clear_pointer (&self->root, json_node_unref);
 
-  dzl_clear_pointer (&self->build_args, g_strfreev);
-  dzl_clear_pointer (&self->command, g_free);
-  dzl_clear_pointer (&self->finish_args, g_strfreev);
-  dzl_clear_pointer (&self->runtime, g_free);
-  dzl_clear_pointer (&self->runtime_version, g_free);
-  dzl_clear_pointer (&self->sdk, g_free);
-  dzl_clear_pointer (&self->sdk_extensions, g_strfreev);
+  g_clear_pointer (&self->build_args, g_strfreev);
+  g_clear_pointer (&self->command, g_free);
+  g_clear_pointer (&self->finish_args, g_strfreev);
+  g_clear_pointer (&self->runtime, g_free);
+  g_clear_pointer (&self->runtime_version, g_free);
+  g_clear_pointer (&self->sdk, g_free);
+  g_clear_pointer (&self->sdk_extensions, g_strfreev);
 
-  dzl_clear_pointer (&self->primary, json_object_unref);
-  dzl_clear_pointer (&self->primary_module, g_free);
-  dzl_clear_pointer (&self->config_opts, g_strfreev);
+  g_clear_pointer (&self->primary, json_object_unref);
+  g_clear_pointer (&self->primary_module, g_free);
+  g_clear_pointer (&self->config_opts, g_strfreev);
 
   G_OBJECT_CLASS (gbp_flatpak_manifest_parent_class)->finalize (object);
 }
