@@ -672,11 +672,18 @@ gbp_flatpak_pipeline_addin_load (IdeBuildPipelineAddin *addin,
   g_autoptr(GError) error = NULL;
   IdeConfiguration *config;
   IdeContext *context;
-  IdeRuntime *runtime;
 
   g_assert (GBP_IS_FLATPAK_PIPELINE_ADDIN (self));
   g_assert (IDE_IS_BUILD_PIPELINE (pipeline));
 
+  config = ide_build_pipeline_get_configuration (pipeline);
+
+  if (!GBP_IS_FLATPAK_MANIFEST (config))
+    {
+      g_message ("Not using flatpak manifest, refusing to add flatpak build pipeline stages");
+      return;
+    }
+
   sniff_flatpak_builder_version (self);
 
   if (VERSION_CHECK (&self->version, 0, 10, 5))
@@ -697,20 +704,6 @@ gbp_flatpak_pipeline_addin_load (IdeBuildPipelineAddin *addin,
                                           NULL);
     }
 
-  config = ide_build_pipeline_get_configuration (pipeline);
-
-  /* TODO: Once we have GbpFlatpakConfiguration, we can check for
-   *       that (and it should only allow for valid flatpak runtimes).
-   */
-
-  runtime = ide_configuration_get_runtime (config);
-
-  if (!GBP_IS_FLATPAK_RUNTIME (runtime))
-    {
-      g_message ("Configuration is not using flatpak, ignoring pipeline");
-      return;
-    }
-
   /*
    * TODO: We should add the ability to mark a pipeline as broken, if we
    *       detect something that is alarming. That will prevent builds from
@@ -738,7 +731,7 @@ gbp_flatpak_pipeline_addin_unload (IdeBuildPipelineAddin *addin,
   g_assert (GBP_IS_FLATPAK_PIPELINE_ADDIN (self));
   g_assert (IDE_IS_BUILD_PIPELINE (pipeline));
 
-  dzl_clear_pointer (&self->state_dir, g_free);
+  g_clear_pointer (&self->state_dir, g_free);
 }
 
 /* GObject boilerplate */
