@@ -20,9 +20,11 @@
 #include <libpeas/peas.h>
 
 #include "gbp-gcc-pipeline-addin.h"
+#include "gbp-gcc-toolchain-provider.h"
 
 void
 gbp_gcc_register_types (PeasObjectModule *module)
 {
   peas_object_module_register_extension_type (module, IDE_TYPE_BUILD_PIPELINE_ADDIN, GBP_TYPE_GCC_PIPELINE_ADDIN);
+  peas_object_module_register_extension_type (module, IDE_TYPE_TOOLCHAIN_PROVIDER, GBP_TYPE_GCC_TOOLCHAIN_PROVIDER);
 }
