@@ -538,9 +538,11 @@ gbp_gdb_debugger_handle_stopped (GbpGdbDebugger                 *self,
 {
   IdeDebuggerStopReason stop_reason;
   g_autoptr(IdeDebuggerBreakpoint) breakpoint = NULL;
+  g_autoptr(IdeDebuggerThread) thread = NULL;
   g_autofree gchar *file = NULL;
   g_autofree gchar *fullname = NULL;
-  G_GNUC_UNUSED const gchar *thread_id = NULL;
+  const gchar *thread_id = NULL;
+  const gchar *group_id = NULL;
   const struct gdbwire_mi_result *iter;
   const gchar *id = NULL;
   const gchar *reason = NULL;
@@ -573,6 +575,8 @@ gbp_gdb_debugger_handle_stopped (GbpGdbDebugger                 *self,
             disp = iter->variant.cstring;
           else if (g_strcmp0 (iter->variable, "bkptno") == 0)
             id = iter->variant.cstring;
+          else if (g_strcmp0 (iter->variable, "group-id") == 0)
+            group_id = iter->variant.cstring;
         }
       else if (iter->kind == GDBWIRE_MI_TUPLE)
         {
@@ -656,6 +660,10 @@ gbp_gdb_debugger_handle_stopped (GbpGdbDebugger                 *self,
 
   gbp_gdb_debugger_reload_breakpoints (self);
 
+  thread = ide_debugger_thread_new (thread_id);
+  ide_debugger_thread_set_group (thread, group_id);
+
+  ide_debugger_emit_thread_selected (IDE_DEBUGGER (self), thread);
   ide_debugger_emit_stopped (IDE_DEBUGGER (self), stop_reason, breakpoint);
 }
 
@@ -1976,6 +1984,7 @@ gbp_gdb_debugger_list_locals_async (IdeDebugger         *debugger,
   g_autoptr(IdeTask) task = NULL;
   g_autofree gchar *command = NULL;
   guint depth;
+  const gchar *tid = NULL;
 
   g_assert (GBP_IS_GDB_DEBUGGER (self));
   g_assert (IDE_IS_DEBUGGER_THREAD (thread));
@@ -1986,14 +1995,13 @@ gbp_gdb_debugger_list_locals_async (IdeDebugger         *debugger,
   ide_task_set_priority (task, G_PRIORITY_LOW);
   ide_task_set_source_tag (task, gbp_gdb_debugger_list_locals_async);
 
+  tid = ide_debugger_thread_get_id (thread);
   depth = ide_debugger_frame_get_depth (frame);
-  command = g_strdup_printf ("9999-stack-select-frame %u\n"
-                             "@@@@-stack-list-locals --simple-values\n"
-                             "9999-stack-select-frame",
-                             depth);
+  command = g_strdup_printf ("@@@@-stack-list-variables --thread %s --frame %u --simple-values\n",
+                             tid, depth);
 
   gbp_gdb_debugger_exec_async (self,
-                               thread,
+                               NULL,
                                command,
                                cancellable,
                                gbp_gdb_debugger_list_locals_cb,
@@ -2428,7 +2436,7 @@ gbp_gdb_debugger_prepare (IdeDebugger *debugger,
     self->mapped_fd = ide_runner_take_fd (runner, tty_fd, -1);
 
   /* We need access to stdin/stdout for communicating with gdb */
-  ide_runner_set_flags (runner, G_SUBPROCESS_FLAGS_STDIN_PIPE | G_SUBPROCESS_FLAGS_STDOUT_PIPE);
+  ide_runner_set_flags (runner, G_SUBPROCESS_FLAGS_STDIN_PIPE | G_SUBPROCESS_FLAGS_STDOUT_PIPE | G_SUBPROCESS_FLAGS_STDERR_SILENCE);
 
   IDE_EXIT;
 }
