@@ -70,7 +70,7 @@ has_flag (const gchar *contents,
 }
 
 static void
-gbp_qemu_device_provider_load_worker (GTask        *task,
+gbp_qemu_device_provider_load_worker (IdeTask      *task,
                                       gpointer      source_object,
                                       gpointer      task_data,
                                       GCancellable *cancellable)
@@ -83,7 +83,7 @@ gbp_qemu_device_provider_load_worker (GTask        *task,
 
   IDE_ENTRY;
 
-  g_assert (G_IS_TASK (task));
+  g_assert (IDE_IS_TASK (task));
   g_assert (GBP_IS_QEMU_DEVICE_PROVIDER (source_object));
   g_assert (!cancellable || G_IS_CANCELLABLE (cancellable));
 
@@ -95,33 +95,33 @@ gbp_qemu_device_provider_load_worker (GTask        *task,
 
   if (!ide_g_host_file_get_contents ("/proc/mounts", &mounts, NULL, &error))
     {
-      g_task_return_error (task, g_steal_pointer (&error));
+      ide_task_return_error (task, g_steal_pointer (&error));
       IDE_EXIT;
     }
 
   /* @mounts is guaranteed to have a \0 suffix */
   if (strstr (mounts, "binfmt") == NULL)
     {
-      g_task_return_new_error (task,
-                               G_IO_ERROR,
-                               G_IO_ERROR_FAILED,
-                               "binfmt is missing from /proc/mounts");
+      ide_task_return_new_error (task,
+                                 G_IO_ERROR,
+                                 G_IO_ERROR_FAILED,
+                                 "binfmt is missing from /proc/mounts");
       IDE_EXIT;
     }
 
   if (!ide_g_host_file_get_contents  ("/proc/sys/fs/binfmt_misc/status", &status, NULL, &error))
     {
-      g_task_return_error (task, g_steal_pointer (&error));
+      ide_task_return_error (task, g_steal_pointer (&error));
       IDE_EXIT;
     }
 
   /* @status is guaranteed to have a \0 suffix */
   if (!g_str_equal (g_strstrip (status), "enabled"))
     {
-      g_task_return_new_error (task,
-                               G_IO_ERROR,
-                               G_IO_ERROR_FAILED,
-                               "binfmt hooks are not currently enabled");
+      ide_task_return_new_error (task,
+                                 G_IO_ERROR,
+                                 G_IO_ERROR_FAILED,
+                                 "binfmt hooks are not currently enabled");
       IDE_EXIT;
     }
 
@@ -148,6 +148,7 @@ gbp_qemu_device_provider_load_worker (GTask        *task,
           has_flag (contents, len, 'F'))
         {
           g_autoptr(IdeLocalDevice) device = NULL;
+          g_autoptr(IdeTriplet) triplet = NULL;
           g_autofree gchar *display_name = NULL;
 
           IDE_TRACE_MSG ("Discovered QEMU device \"%s\"\n", machines[i].arch);
@@ -157,9 +158,10 @@ gbp_qemu_device_provider_load_worker (GTask        *task,
                                           g_get_host_name (),
                                           machines[i].suffix);
 
+          triplet = ide_triplet_new (machines[i].arch);
           device = g_object_new (IDE_TYPE_LOCAL_DEVICE,
                                  "id", machines[i].filename,
-                                 "arch", machines[i].arch,
+                                 "triplet", triplet,
                                  "context", context,
                                  "display-name", display_name,
                                  NULL);
@@ -167,9 +169,9 @@ gbp_qemu_device_provider_load_worker (GTask        *task,
         }
     }
 
-  g_task_return_pointer (task,
-                         g_steal_pointer (&devices),
-                         (GDestroyNotify)g_ptr_array_unref);
+  ide_task_return_pointer (task,
+                           g_steal_pointer (&devices),
+                           (GDestroyNotify)g_ptr_array_unref);
 
   IDE_EXIT;
 }
@@ -181,23 +183,23 @@ gbp_qemu_device_provider_load_async (IdeDeviceProvider   *provider,
                                      GAsyncReadyCallback  callback,
                                      gpointer             user_data)
 {
-  g_autoptr(GTask) task = NULL;
+  g_autoptr(IdeTask) task = NULL;
 
   IDE_ENTRY;
 
   g_assert (GBP_IS_QEMU_DEVICE_PROVIDER (provider));
   g_assert (!cancellable || G_IS_CANCELLABLE (cancellable));
 
-  task = g_task_new (provider, cancellable, callback, user_data);
-  g_task_set_source_tag (task, gbp_qemu_device_provider_load_async);
+  task = ide_task_new (provider, cancellable, callback, user_data);
+  ide_task_set_source_tag (task, gbp_qemu_device_provider_load_async);
 
 #ifdef __linux__
-  g_task_run_in_thread (task, gbp_qemu_device_provider_load_worker);
+  ide_task_run_in_thread (task, gbp_qemu_device_provider_load_worker);
 #else
-  g_task_return_new_error (task,
-                           G_IO_ERROR,
-                           G_IO_ERROR_NOT_SUPPORTED,
-                           "Qemu device hooks are only supported on Linux");
+  ide_task_return_new_error (task,
+                             G_IO_ERROR,
+                             G_IO_ERROR_NOT_SUPPORTED,
+                             "Qemu device hooks are only supported on Linux");
 #endif
 
   IDE_EXIT;
@@ -215,7 +217,7 @@ gbp_qemu_device_provider_load_finish (IdeDeviceProvider  *provider,
   g_assert (IDE_IS_DEVICE_PROVIDER (provider));
   g_assert (G_IS_ASYNC_RESULT (result));
 
-  if ((devices = g_task_propagate_pointer (G_TASK (result), error)))
+  if ((devices = ide_task_propagate_pointer (IDE_TASK (result), error)))
     {
       for (guint i = 0; i < devices->len; i++)
         {
