@@ -3,8 +3,8 @@
 #
 # __init__.py
 #
-# Copyright © 2016 Christian Hergert <chergert@redhat.com>
-# Copyright © 2017 Georg Vienna <georg.vienna@himbarsoft.com>
+# Copyright 2016 Christian Hergert <chergert@redhat.com>
+# Copyright 2017 Georg Vienna <georg.vienna@himbarsoft.com>
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -83,7 +83,8 @@ class RustUpWorkbenchAddin(GObject.Object, Ide.WorkbenchAddin):
         workbench.connect('unload', unload)
 
     def do_unload(self, workbench):
-        RustupApplicationAddin.instance.workbenches.discard(workbench)
+        if RustupApplicationAddin.instance:
+            RustupApplicationAddin.instance.workbenches.discard(workbench)
 
 _NO_RUSTUP = _('Rustup not installed')
 
