@@ -81,7 +81,7 @@ task_state_free (gpointer data)
   g_assert (state != NULL);
 
   g_clear_object (&state->file);
-  dzl_clear_pointer (&state->hash_table, g_hash_table_unref);
+  g_clear_pointer (&state->hash_table, g_hash_table_unref);
   g_slice_free (TaskState, state);
 }
 
@@ -277,7 +277,7 @@ gbp_spell_dict_get_words_async (GbpSpellDict        *self,
 
   task = ide_task_new (self, cancellable, callback, user_data);
   ide_task_set_source_tag (task, gbp_spell_dict_get_words_async);
-  ide_task_set_task_data (task, state, (GDestroyNotify)task_state_free);
+  ide_task_set_task_data (task, state, task_state_free);
 
   dict_filename = g_strconcat (gspell_language_get_code (self->language), ".dic", NULL);
   path = g_build_filename (g_get_user_config_dir (), "enchant", dict_filename, NULL);
@@ -323,7 +323,7 @@ gbp_spell_dict_get_dict_words_cb (GObject      *object,
     }
   else
     {
-      dzl_clear_pointer (&self->words, g_hash_table_unref);
+      g_clear_pointer (&self->words, g_hash_table_unref);
       self->words = g_hash_table_ref (words);
       self->init_status = INIT_DONE;
 
@@ -370,7 +370,7 @@ gbp_spell_dict_set_dict (GbpSpellDict         *self,
       enchant_broker_free_dict (self->broker, self->dict);
       self->dict = NULL;
 
-      dzl_clear_pointer (&self->words, g_hash_table_unref);
+      g_clear_pointer (&self->words, g_hash_table_unref);
     }
 }
 
@@ -463,13 +463,13 @@ gbp_spell_dict_finalize (GObject *object)
     {
       if (self->dict != NULL)
         enchant_broker_free_dict (self->broker, self->dict);
-      dzl_clear_pointer (&self->broker, enchant_broker_free);
+      g_clear_pointer (&self->broker, enchant_broker_free);
     }
 
   if (self->words != NULL)
     {
       g_hash_table_remove_all (self->words);
-      dzl_clear_pointer (&self->words, g_hash_table_unref);
+      g_clear_pointer (&self->words, g_hash_table_unref);
     }
 
   G_OBJECT_CLASS (gbp_spell_dict_parent_class)->finalize (object);
