@@ -20,6 +20,7 @@
 #include <ide.h>
 
 #include "gbp-symbol-layout-stack-addin.h"
+#include "gbp-symbol-hover-provider.h"
 
 void
 gbp_symbol_tree_register_types (PeasObjectModule *module)
@@ -27,4 +28,7 @@ gbp_symbol_tree_register_types (PeasObjectModule *module)
   peas_object_module_register_extension_type (module,
                                               IDE_TYPE_LAYOUT_STACK_ADDIN,
                                               GBP_TYPE_SYMBOL_LAYOUT_STACK_ADDIN);
+  peas_object_module_register_extension_type (module,
+                                              IDE_TYPE_HOVER_PROVIDER,
+                                              GBP_TYPE_SYMBOL_HOVER_PROVIDER);
 }
