@@ -265,7 +265,7 @@ gbp_sysroot_toolchain_provider_load_finish (IdeToolchainProvider  *provider,
   if (toolchains == NULL)
     return FALSE;
 
-  dzl_clear_pointer (&self->toolchains, g_ptr_array_unref);
+  g_clear_pointer (&self->toolchains, g_ptr_array_unref);
   self->toolchains = g_ptr_array_ref (toolchains);
 
   for (guint i = 0; i < toolchains->len; i++)
@@ -289,7 +289,7 @@ gbp_sysroot_toolchain_provider_unload (IdeToolchainProvider  *provider,
   g_assert (GBP_IS_SYSROOT_TOOLCHAIN_PROVIDER (self));
   g_assert (IDE_IS_TOOLCHAIN_MANAGER (manager));
 
-  dzl_clear_pointer (&self->toolchains, g_ptr_array_unref);
+  g_clear_pointer (&self->toolchains, g_ptr_array_unref);
 }
 
 static void
