@@ -199,7 +199,7 @@ on_run_manager_run (GbTerminalWorkbenchAddin *self,
                            "pty", pty,
                            "visible", TRUE,
                            NULL);
-      dzl_set_weak_pointer (&self->run_terminal, view);
+      g_set_weak_pointer (&self->run_terminal, view);
 
       panel = g_object_new (DZL_TYPE_DOCK_WIDGET,
                             "child", self->run_terminal,
@@ -208,7 +208,7 @@ on_run_manager_run (GbTerminalWorkbenchAddin *self,
                             "title", _("Application Output"),
                             "visible", TRUE,
                             NULL);
-      dzl_set_weak_pointer (&self->run_panel, panel);
+      g_set_weak_pointer (&self->run_panel, panel);
 
       perspective = ide_workbench_get_perspective_by_name (self->workbench, "editor");
       g_assert (IDE_IS_EDITOR_PERSPECTIVE (perspective));
@@ -335,7 +335,7 @@ gb_terminal_workbench_addin_load (IdeWorkbenchAddin *addin,
 
   context = ide_workbench_get_context (workbench);
 
-  dzl_set_weak_pointer (&self->workbench, workbench);
+  g_set_weak_pointer (&self->workbench, workbench);
 
   g_action_map_add_action_entries (G_ACTION_MAP (workbench), actions, G_N_ELEMENTS (actions), self);
   gb_terminal_workbench_setup_shortcuts (self, workbench);
@@ -407,13 +407,13 @@ gb_terminal_workbench_addin_unload (IdeWorkbenchAddin *addin,
   if (self->panel_dock_widget != NULL)
     {
       gtk_widget_destroy (self->panel_dock_widget);
-      dzl_clear_weak_pointer (&self->panel_dock_widget);
+      g_clear_weak_pointer (&self->panel_dock_widget);
     }
 
   if (self->run_panel != NULL)
     {
       gtk_widget_destroy (self->run_panel);
-      dzl_clear_weak_pointer (&self->run_panel);
+      g_clear_weak_pointer (&self->run_panel);
     }
 }
 
