@@ -163,7 +163,7 @@ state_stack_pop (MatchingState *state)
     return FALSE;
 
   item = &g_array_index (state->stack, StateStackItem, len - 1);
-  dzl_clear_pointer (&state->children, g_ptr_array_unref);
+  g_clear_pointer (&state->children, g_ptr_array_unref);
 
   state->children = item->children;
   state->candidate_node = item->candidate_node;
@@ -384,8 +384,8 @@ completion_item_new (const gchar     *label,
 static void
 completion_item_free (CompletionItem *item)
 {
-  dzl_clear_pointer (&item->label, g_free);
-  dzl_clear_pointer (&item->define, ide_xml_rng_define_unref);
+  g_clear_pointer (&item->label, g_free);
+  g_clear_pointer (&item->define, ide_xml_rng_define_unref);
   g_slice_free (CompletionItem, item);
 }
 
@@ -452,9 +452,9 @@ matching_state_free (MatchingState *state)
   g_clear_object (&state->parent_node);
   g_clear_object (&state->candidate_node);
 
-  dzl_clear_pointer (&state->prefix, g_free);
-  dzl_clear_pointer (&state->children, g_ptr_array_unref);
-  dzl_clear_pointer (&state->stack, g_array_unref);
+  g_clear_pointer (&state->prefix, g_free);
+  g_clear_pointer (&state->children, g_ptr_array_unref);
+  g_clear_pointer (&state->stack, g_array_unref);
 
   g_slice_free (MatchingState, state);
 }
@@ -1051,7 +1051,7 @@ ide_xml_completion_provider_populate_async (IdeCompletionProvider *provider,
   state->line = gtk_text_iter_get_line (&iter) + 1;
   state->line_offset = gtk_text_iter_get_line_offset (&iter) + 1;
 
-  ide_task_set_task_data (task, state, (GDestroyNotify)populate_state_free);
+  ide_task_set_task_data (task, state, populate_state_free);
 
   ide_xml_service_get_position_from_cursor_async (service,
                                                   state->ifile,
