@@ -18,7 +18,6 @@
 
 #pragma once
 
-#include <gtksourceview/gtksource.h>
 #include <ide.h>
 
 G_BEGIN_DECLS
@@ -27,6 +26,4 @@ G_BEGIN_DECLS
 
 G_DECLARE_FINAL_TYPE (IdeXmlCompletionProvider, ide_xml_completion_provider, IDE, XML_COMPLETION_PROVIDER, IdeObject)
 
-IdeXmlCompletionProvider *ide_xml_completion_provider_new (void);
-
 G_END_DECLS
