@@ -45,9 +45,10 @@ struct _IdeXmlPosition
   gint                  child_pos;
   gchar                 quote;
 
-  guint                 ref_count;
+  volatile gint         ref_count;
 };
 
+GType                     ide_xml_position_get_type             (void);
 IdeXmlPosition           *ide_xml_position_new                  (IdeXmlSymbolNode      *node,
                                                                  const gchar           *prefix,
                                                                  IdeXmlPositionKind     kind,
