@@ -16,7 +16,6 @@
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
-#include <dazzle.h>
 #include <glib/gi18n.h>
 #include <string.h>
 
@@ -176,7 +175,7 @@ ide_xml_sax_parse (IdeXmlSax   *self,
   wellformed = self->context->wellFormed;
 
   self->context->sax = NULL;
-  dzl_clear_pointer (&self->context, xmlFreeParserCtxt);
+  g_clear_pointer (&self->context, xmlFreeParserCtxt);
 
   return wellformed;
 }
