@@ -60,7 +60,7 @@ IdeXmlSchema *
 ide_xml_schema_ref (IdeXmlSchema *self)
 {
   g_return_val_if_fail (self, NULL);
-  g_return_val_if_fail (self->ref_count, NULL);
+  g_return_val_if_fail (self->ref_count > 0, NULL);
 
   g_atomic_int_inc (&self->ref_count);
 
@@ -71,7 +71,7 @@ void
 ide_xml_schema_unref (IdeXmlSchema *self)
 {
   g_return_if_fail (self);
-  g_return_if_fail (self->ref_count);
+  g_return_if_fail (self->ref_count > 0);
 
   if (g_atomic_int_dec_and_test (&self->ref_count))
     ide_xml_schema_free (self);
