@@ -156,14 +156,14 @@ ide_xml_service_load_schema_cb3 (GObject      *object,
           else
             {
               /* TODO: get parse error ? */
-              dzl_clear_pointer (&cache_entry->content, g_bytes_unref);
+              g_clear_pointer (&cache_entry->content, g_bytes_unref);
               cache_entry->state = SCHEMA_STATE_CANT_PARSE;
             }
         }
       else
         {
           /* TODO: set error message */
-          dzl_clear_pointer (&cache_entry->content, g_bytes_unref);
+          g_clear_pointer (&cache_entry->content, g_bytes_unref);
           cache_entry->state = SCHEMA_STATE_WRONG_FILE_TYPE;
         }
     }
@@ -1026,7 +1026,7 @@ ide_xml_service_get_position_from_cursor_async (IdeXmlService       *self,
   state->line = line;
   state->line_offset = line_offset;
 
-  ide_task_set_task_data (task, state, (GDestroyNotify)position_state_free);
+  ide_task_set_task_data (task, state, position_state_free);
 
   ide_xml_service_get_analysis_async (self,
                                       ifile,
