@@ -69,8 +69,8 @@ tree_builder_state_free (TreeBuilderState *state)
 {
   g_assert (state != NULL);
 
-  dzl_clear_pointer (&state->content, g_bytes_unref);
-  dzl_clear_pointer (&state->analysis, ide_xml_analysis_unref);
+  g_clear_pointer (&state->content, g_bytes_unref);
+  g_clear_pointer (&state->analysis, ide_xml_analysis_unref);
   g_clear_object (&state->file);
   g_slice_free (TreeBuilderState, state);
 }
@@ -133,7 +133,7 @@ fetch_schema_state_free (FetchSchemasState *state)
 {
   g_assert (state != NULL);
 
-  dzl_clear_pointer (&state->schemas, g_ptr_array_unref);
+  g_clear_pointer (&state->schemas, g_ptr_array_unref);
   g_clear_object (&state->self);
   g_clear_object (&state->task);
   g_slice_free (FetchSchemasState, state);
@@ -167,7 +167,7 @@ fetch_schemas_cb (GObject      *object,
       if (cache_entry->content != NULL &&
           entry->content != cache_entry->content)
         {
-          dzl_clear_pointer (&entry->content, g_bytes_unref);
+          g_clear_pointer (&entry->content, g_bytes_unref);
           entry->content = g_bytes_ref (cache_entry->content);
         }
 
@@ -181,7 +181,7 @@ fetch_schemas_cb (GObject      *object,
       if (cache_entry->schema != NULL &&
           entry->schema != cache_entry->schema)
         {
-          dzl_clear_pointer (&entry->schema, ide_xml_schema_unref);
+          g_clear_pointer (&entry->schema, ide_xml_schema_unref);
           entry->schema = ide_xml_schema_ref (cache_entry->schema);
         }
 
@@ -531,7 +531,7 @@ ide_xml_tree_builder_build_tree_async (IdeXmlTreeBuilder   *self,
 
   ide_task_set_task_data (task,
                           g_steal_pointer (&state),
-                          (GDestroyNotify)tree_builder_state_free);
+                          tree_builder_state_free);
 
   ide_xml_parser_get_analysis_async (self->parser,
                                      file,
