@@ -1,6 +1,6 @@
 /* test-ide-buffer-manager.c
  *
- * Copyright © 2015 Christian Hergert <christian@hergert.me>
+ * Copyright 2015 Christian Hergert <christian@hergert.me>
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -184,7 +184,7 @@ main (gint   argc,
   ide_log_init (TRUE, NULL);
   ide_log_set_verbosity (4);
 
-  app = ide_application_new ();
+  app = ide_application_new (IDE_APPLICATION_MODE_TESTS);
   ide_application_add_test (app, "/Ide/BufferManager/basic", test_buffer_manager_basic, NULL, required_plugins);
   gnome_builder_plugins_init ();
   ret = g_application_run (G_APPLICATION (app), argc, argv);
